@@ -1,30 +1,27 @@
-'''
+"""
 Configuration center.
 Use https://www.dynaconf.com/
-'''''
-import os
+""" ""
 import sys
 from pathlib import Path
 
-from dynaconf import Dynaconf
-
+from dynaconf import Dynaconf  # type: ignore
 
 _base_dir = Path(__file__).parent.parent
 
 _settings_files = [
     # All config file will merge.
-    Path(__file__).parent / 'settings.yml',  # Load default config.
+    Path(__file__).parent
+    / "settings.yml",  # Load default config.
 ]
 
 # User configuration. It will be created automatically by the pip installer .
-_external_files = [
-    Path(sys.prefix, 'etc', 'textwatermark', 'settings.yml')
-]
+_external_files = [Path(sys.prefix, "etc", "textwatermark", "settings.yml")]
 
 
 settings = Dynaconf(
     # Set env `TEXTWATERMARK_FOO='bar'`，use `settings.FOO` .
-    envvar_prefix='TEXTWATERMARK',
+    envvar_prefix="TEXTWATERMARK",
     settings_files=_settings_files,  # load user configuration.
     # environments=True,  # Enable multi-level configuration，eg: default, development, production
     load_dotenv=True,  # Enable load .env
