@@ -1,4 +1,4 @@
-'''
+"""
 Insert the selected character after the text to represent a 1 in binary, otherwise 0.
 
 The characters are from [combining_chars][], [invisible_chars][] and [whitespace_chars][].
@@ -16,17 +16,18 @@ Info: Differents between combining_chars, invisible_chars and whitespace_chars
     [whitespace_chars][]: There is a small but recognizable difference in 
     the spacing of characters before and after watermarking
 
-'''
+"""
 
 from textwatermark.defines import WMMethod
-from textwatermark.templates import (combining_chars, invisible_chars,
-                                     whitespace_chars)
+from textwatermark.templates import combining_chars, invisible_chars, whitespace_chars
 
-CONFUSABLES_CHARS_LIST = combining_chars.CONFUSABLES_CHARS + \
-    invisible_chars.CONFUSABLES_CHARS + whitespace_chars.CONFUSABLES_CHARS + \
-    ['\u007F']
+CONFUSABLES_CHARS_LIST: list = (
+    combining_chars.CONFUSABLES_CHARS
+    + invisible_chars.CONFUSABLES_CHARS
+    + whitespace_chars.CONFUSABLES_CHARS
+    + ["\u007F"]
+)
 
-CONFUSABLES_CHARS = dict(
-    zip(CONFUSABLES_CHARS_LIST, CONFUSABLES_CHARS_LIST))
+CONFUSABLES_CHARS: dict = dict(zip(CONFUSABLES_CHARS_LIST, CONFUSABLES_CHARS_LIST))
 
-method = WMMethod.APPEND_AS_BINARY
+method: WMMethod = WMMethod.APPEND_AS_BINARY
