@@ -1,14 +1,14 @@
-'''
+"""
 This template will replace the regular space char with the other width of space chars.
 
 Since spaces are rare in Chinese, this template is mainly suitable for English text.
-'''
+"""
 
 from textwatermark.defines import WhiteSpaceChars, WMMethod
 
 # 空格字符
-CONFUSABLES_CHARS = {
-    '\u0020': [
+CONFUSABLES_CHARS: dict = {
+    "\u0020": [
         WhiteSpaceChars.SPACE_1_4.value,
         # WhiteSpaceChars.NO_BREAK_SPACE_1_4.value,
         # WhiteSpaceChars.EN_QUAD_1_2.value,
@@ -27,4 +27,4 @@ CONFUSABLES_CHARS = {
     ]
 }
 
-method = WMMethod.FIND_AND_REPLACE
+method: WMMethod = WMMethod.FIND_AND_REPLACE
